@@ -9,4 +9,4 @@ from .. import models
 admin.site.register(models.CloudStackOffering, CloudStackServiceofferingAdmin)
 admin.site.register(models.CloudStackBundle, CloudStackBundleAdmin)
 admin.site.register(models.CloudStackRegion, CloudStackRegionAdmin)
-admin.site.register(models.CloudStackRegion, CloudStackPackAdmin)
+admin.site.register(models.CloudStackPack, CloudStackPackAdmin)
